# Savant Audio Switch Client

[![image](https://img.shields.io/pypi/v/savantaudio-client.svg)](https://pypi.org/project/savantaudio-client/)

The savantaudio-client package allows users to download the contents of this [GiHub repository](https://github.com/akropp/savantaudio-client),  containing a client library to control Savant Audio Switches such as the SSA-3220/SSA-3220D.

## Installing

Install and update using [pip](https://pip.pypa.io/en/stable/quickstart/):

```bash
pip3 install savantaudio-client
```

## Downloading a Python Package Template Project

To down load the latest version of the Python Package Template project located in [this GiHub repository](https://github.com/akropp/savantaudio-client), execute the following command from the command line:

```bash
savantaudio-client install
```

This will be downloaded to the current directory and will contain the following directory structure:

```bash
savantaudio-client/
 |-- docs/
 |-- |-- build_html/
 |-- |-- build_latex/
 |-- |-- source/
 |-- py-pkg/
 |-- |-- __init__.py
 |-- |-- __version__.py
 |-- |-- client.py
 |-- |-- entry_points.py
 |-- tests/
 |-- |   __init__.py
 |-- |   test.py
 |-- .env
 |-- .gitignore
 |-- README.md
 |-- setup.cfg
 |-- pyproject.toml
 |-- LICENSE
```
